@@ -18,31 +18,9 @@ import gocept.registration.interfaces
 import persistent
 import sha
 import zope.app.container.btree
+import zope.app.container.contained
 import zope.interface
 
-class Registrations(zope.app.container.btree.BTreeContainer):
-
-    zope.interface.implements(gocept.registration.interfaces.IRegistrations)
-
-    def _createHash(self, email, data=None):
-        return sha.new(email+datetime.datetime.now().isoformat()).hexdigest()
-
-    def register(self, email, data=None):
-        """Create a new registration for the given email address and data."""
-        hash = self._createHash(email, data)
-        self[hash] = registration = Registration(hash, email, data)
-        return registration
-
-    def confirm(self, hash):
-        """Confirm the registration identified by the hash."""
-        registration = self[hash]
-
-        event = gocept.registration.interfaces.RegistrationConfirmedEvent(
-            registration)
-        zope.event.notify(event)
-
-        del self[hash]
-
 
 class Registration(zope.app.container.contained.Contained,
                    persistent.Persistent):
@@ -53,3 +31,27 @@ class Registration(zope.app.container.contained.Contained,
         self.hash = hash
         self.email = email
         self.data = data
+
+
+class Registrations(zope.app.container.btree.BTreeContainer):
+
+    zope.interface.implements(gocept.registration.interfaces.IRegistrations)
+
+    def _createHash(self, email, data=None):
+        return sha.new(email+datetime.datetime.now().isoformat()).hexdigest()
+
+    def register(self, email, data=None, factory=Registration):
+        """Create a new registration for the given email address and data."""
+        hash = self._createHash(email, data)
+        self[hash] = registration = factory(hash, email, data)
+        return registration
+
+    def confirm(self, hash):
+        """Confirm the registration identified by the hash."""
+        registration = self[hash]
+
+        event = gocept.registration.interfaces.RegistrationConfirmedEvent(
+            registration)
+        zope.event.notify(event)
+
+        del self[hash]
